( cd usr/X11R7/lib ; rm -rf libGL.so )
( cd usr/X11R7/lib ; ln -sf libGL.so.1 libGL.so )
( cd usr/X11R7/lib ; rm -rf libGLw.so )
( cd usr/X11R7/lib ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/X11R7/lib ; rm -rf libGLU.so.1 )
( cd usr/X11R7/lib ; ln -sf libGLU.so.1.3.070200 libGLU.so.1 )
( cd usr/X11R7/lib ; rm -rf libglut.so )
( cd usr/X11R7/lib ; ln -sf libglut.so.3 libglut.so )
( cd usr/X11R7/lib ; rm -rf libglut.so.3 )
( cd usr/X11R7/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/X11R7/lib ; rm -rf libGLw.so.1 )
( cd usr/X11R7/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/X11R7/lib ; rm -rf libGL.so.1 )
( cd usr/X11R7/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/X11R7/lib ; rm -rf libGLU.so )
( cd usr/X11R7/lib ; ln -sf libGLU.so.1 libGLU.so )
( cd usr/include ; rm -rf GL )
( cd usr/include ; ln -sf ../X11R7/include/GL GL )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf ../X11R7/lib/libGL.so libGL.so )
( cd usr/lib ; rm -rf libGLU.so )
( cd usr/lib ; ln -sf ../X11R7/lib/libGLU.so libGLU.so )
( cd usr/lib ; rm -rf libGLw.so )
( cd usr/lib ; ln -sf ../X11R7/lib/libGLw.so libGLw.so )
( cd usr/lib ; rm -rf libglut.so )
( cd usr/lib ; ln -sf ../X11R7/lib/libglut.so libglut.so )
